@@ -12,8 +12,8 @@ use Params::Validate ':all';
 our ($VERSION, @EXPORT_OK, %EXPORT_TAGS);
 my @subs;
 
-$VERSION = '0.6_03';
-@subs = qw(exact_wrap fuzzy_wrap wrap_smart);
+$VERSION = '0.7_01';
+@subs = qw(exact_wrap fuzzy_wrap);
 @EXPORT_OK = @subs;
 %EXPORT_TAGS = ('all' => [ @subs ]);
 
@@ -146,23 +146,6 @@ sub _validate
     );
 }
 
-# deprecated on 2016-09-06
-sub wrap_smart
-{
-    my ($text, $conf) = @_;
-    croak "wrap_smart(\$text [, { options } ])\n" unless defined $text;
-
-    my $msg_size    =  $conf->{max_msg_size} || WRAP_AT_DEFAULT;
-    my $exact_split = !$conf->{no_split};
-
-    warn 'wrap_smart() is deprecated, use ', $exact_split ? 'exact_wrap()' : 'fuzzy_wrap()', " here instead.\n";
-
-    my $average = $calc_average->($text, $msg_size);
-    my $wrapper = $exact_split ? \&_exact_wrap : \&_fuzzy_wrap;
-
-    return $wrapper->($text, $average);
-}
-
 1;
 __END__
 
@@ -174,13 +157,11 @@ Text::Wrap::Smart - Wrap text into chunks of similar length
 
  use Text::Wrap::Smart ':all';
  # or
- use Text::Wrap::Smart qw(exact_wrap fuzzy_wrap wrap_smart);
+ use Text::Wrap::Smart qw(exact_wrap fuzzy_wrap);
 
  @chunks = exact_wrap($text, $wrap_at);
  @chunks = fuzzy_wrap($text, $wrap_at);
 
- @chunks = wrap_smart($text, \%options); # DEPRECATED
-
 =head1 DESCRIPTION
 
 C<Text::Wrap::Smart> is the pure perl companion of C<Text::Wrap::Smart::XS>.
@@ -210,21 +191,11 @@ characters until the first whitespace encountered form a chunk).
 Optionally a wrapping length may be specified; if no length is supplied,
 a default of 160 will be assumed.
 
-=head2 wrap_smart (DEPRECATED)
-
- @chunks = wrap_smart($text [, { options } ]);
-
-The C<options> hash reference may contain the C<no_split> option which specifies
-that words shall not be broken up (i.e., fuzzy wrapping); if C<no_split> is not
-set, exact wrapping will be applied). The C<max_msg_size> option used to set the
-character length boundary for each chunk emitted, but has been changed to set the
-wrapping length now.
-
 =head1 EXPORT
 
 =head2 Functions
 
-C<exact_wrap(), fuzzy_wrap() and wrap_smart()> are exportable.
+C<exact_wrap(), fuzzy_wrap()> are exportable.
 
 =head2 Tags
 
